do

local symbols = { }

symbols["LibWiki.CreateNavigator"] = {
	summary = [[
Create a new page navigator.]],
	signatures = {
		"navigator = LibWiki.CreateNavigator(animated, container) -- Navigator <- boolean, PageContainer",
	},
	parameter = {
		["animated"] = "Controls whether the Navigator uses animations in the provided page container.",
		["container"] = "The page container this Navigator controls.",
	},
	result = {
		["navigator"] = "A new Navigator object.",
	},
	type = "function",
}

symbols["Navigator"] = {
	summary = [[
A navigator controls the content of a page container. It has methods for pushing, popping pages and moving forward/backward through its history.

Important: Never use more than one navigator per page container.]],
	type = "type",
}

symbols["Navigator:PushPage"] = {
	summary = [[
Push a new page onto the currently displayed page in the page stack and display it in the associated page container. If the current page was not the top of the page stack then the remaining stack is discarded and replaced with the new page. If both the module and path equal those of the currently displayed page the method does nothing.]],
	signatures = {
		"Navigator:PushPage(module, path) -- string, string",
	},
	parameter = {
		["module"] = "The module containg the page to be displayed.",
		["path"] = "The path of the page being displayed.",
	},
	result = {
	},
	type = "function",
}

symbols["Navigator:PopPage"] = {
	summary = [[
Pop a page from the page stack. If the currently displayed page is on top of the stack the associated page container will display the next page on the stack. The call has no effect if the page stack is empty or contains only one page.]],
	signatures = {
		"Navigator:PopPage()",
		"Navigator:PopPage(n) -- number",
	},
	parameter = {
		["n"] = "The number of pages to pop from the stack. Defaults to 1.",
	},
	result = {
	},
	type = "function",
}

symbols["Navigator:GoForward"] = {
	summary = [[
Navigate to the next upper page on the page stack and display it in the associated page container. Has no effect if already displaying the top of the page stack.]],
	signatures = {
		"Navigator:GoForward()",
	},
	parameter = {
	},
	result = {
	},
	type = "function",
}

symbols["Navigator:GoBackward"] = {
	summary = [[
Navigate to the next lower page on the page stack and display it in the associated page container. Has no effect if already displaying the bottom of the page stack.]],
	signatures = {
		"Navigator:GoBackward()",
	},
	parameter = {
	},
	result = {
	},
	type = "function",
}

symbols["Navigator:GoTo"] = {
	summary = [[
Navigate to a page in the page stack at the given index. Has no effect if the index is outside the page stack's boundaries.]],
	signatures = {
		"Navigator:GoTo(n) -- number",
	},
	parameter = {
		["n"] = "The page index in the page stack.",
	},
	result = {
	},
	type = "function",
}

symbols["Navigator:GetPageHistoryDepth"] = {
	summary = [[
Returns the number of pages in the navigator's page history stack.]],
	signatures = {
		"depth = Navigator:GetPageHistoryDepth() -- number",
	},
	parameter = {
	},
	result = {
		["depth"] = "The depth of the navigator's page history stack.",
	},
	type = "function",
}

symbols["Navigator:GetPageHistoryPosition"] = {
	summary = [[
Returns the one-based index of the currently displayed page in the page history stack.]],
	signatures = {
		"position = Navigator:GetPageHistoryPosition() -- number",
	},
	parameter = {
	},
	result = {
		["position"] = "The current page's index. Starts from 1 but may be 0 if the navigator has not displayed any page yet.",
	},
	type = "function",
}

symbols["LibWiki.CreatePageContainer"] = {
	summary = [[
Create a new page navigator.]],
	signatures = {
		"container = LibWiki.CreatePageContainer(parent, animation, duration) -- PageContainer <- Frame, Itnerpolation, number",
	},
	parameter = {
		["parent"] = "The parent frame for the page container.",
		["animation"] = "The interpolation function to use for sliding in/out pages. Refer to <<LibAnimate:INDEX|LibAnimate>> for details.",
		["duration"] = "The duration for the transition animations.",
	},
	result = {
		["container"] = "A new page container frame.",
	},
	type = "function",
}

symbols["PageContainer"] = {
	summary = [[
A frame tailored for displaying and sliding in/out. Intended to be used together with Navigator for LibWiki pages, but can display any kind of UI frame.

You usually do not need to use the page container methods directly (except the standard Frame methods for positioning/sizing) since the Navigator does all the dirty work.]],
	type = "type",
}

symbols["PageContainer:ShowPage"] = {
	summary = [[
Navigate to a page in the page stack at the given index. Has no effect if the index is outside the page stack's boundaries.]],
	signatures = {
		"PageContainer:ShowPage(page, animation, scrollOffset) -- Frame, string, number, function",
		"PageContainer:ShowPage(page, animation, scrollOffset, callback) -- Frame, string, number, function",
	},
	parameter = {
		["page"] = "The page to be displayed. Can be any UI frame.",
		["animation"] = [[
Controls whether the page is being slided in or out.

"slide in" means the page is meant to be "above" and replaces the current page.

"slide out" means the current page is being dismissed to reveal a page which is logically "below".]],
		["scrollOffset"] = "The scrolling offset to display the page at.",
	},
	result = {
	},
	type = "function",
}

symbols["PageContainer:GetContentWidth"] = {
	summary = [[
Get the width of the area where the page content is being displayed.]],
	signatures = {
		"width = PageContainer:GetContentWidth() -- number <- void",
	},
	parameter = {
	},
	result = {
		["width"] = "The width of the area where the page content is being displayed.",
	},
	type = "function",
}

symbols["PageContainer:GetContentHeight"] = {
	summary = [[
Get the height of the area where the page content is being displayed.]],
	signatures = {
		"height = PageContainer:GetContentHeight() -- number <- void",
	},
	parameter = {
	},
	result = {
		["height"] = "The height of the area where the page content is being displayed.",
	},
	type = "function",
}

symbols["PageContainer:GetContentScrollOffset"] = {
	summary = [[
Get scrolling offset of the currently displayed page. This value can be fed back into <<:PageContainer:ShowPage>> to preserve page offsets.]],
	signatures = {
		"offset = PageContainer:GetContentScrollOffset() -- number <- void",
	},
	parameter = {
	},
	result = {
		["offset"] = "The scrolling offset of the currently displayed page.",
	},
	type = "function",
}

symbols["PageContainer:GetCurrentPage"] = {
	summary = [[
Get the currently displayed page.]],
	signatures = {
		"page = PageContainer:GetCurrentPage() -- Frame <- void",
	},
	parameter = {
	},
	result = {
		["page"] = "The currently displayed page.",
	},
	type = "function",
}

symbols["PageContainer:GetPageContentFrame"] = {
	summary = [[
Get the frame which is the direct parent for pages. Manipulating this frame may result in weird behavior.]],
	signatures = {
		"content = PageContainer:GetPageContentFrame() -- Frame <- void",
	},
	parameter = {
	},
	result = {
		["content"] = "The frame used as parent for pages.",
	},
	type = "function",
}

symbols["LibWiki.RegisterPageFactory"] = {
	summary = [[
Create a new page navigator.]],
	signatures = {
		"LibWiki.RegisterPageFactory(module, factory) -- string, PageFactory",
	},
	parameter = {
		["module"] = "The module identifier this factory is responsible for.",
		["factory"] = "The factory object providing concrete pages for page paths.",
	},
	result = {
	},
	type = "function",
}

symbols["PageFactory"] = {
	summary = [[
A page factory is responsible for creating pages for certain paths. The library does not provide any factories since only the factory knows which paths constitute valid pages.

Even though there are no default factories the <<:object:PageBuilder|PageBuilder>> object makes creating pages a cakewalk.]],
	type = "type",
}

symbols["PageFactory:CreatePage"] = {
	summary = [[
A method required by every <<:PageFactory>>. Its job is creating the pages associated with paths.]],
	signatures = {
		"page, title = PageFactory:CreatePage(parent, path) -- Frame, string <- Frame, string",
	},
	parameter = {
		["parent"] = "The frame used as parent for the page.",
		["path"] = "The path to create a page for.",
	},
	result = {
		["page"] = "The page to be displayed.",
		["title"] = "The displayable title for the page.",
	},
	type = "function",
}

symbols["PageBuilder"] = {
	summary = [[
The page builder is a powerful object capable of constructing wiki pages with only small amounts of code.]],
	type = "type",
}

symbols["LibWiki.CreatePageBuilder"] = {
	summary = [[
Create a new page builder with the given page style.]],
	signatures = {
		"builder = LibWiki.CreatePageBuilder(style) -- PageBuilder <- PageStyle/nil",
	},
	parameter = {
		["style"] = "The style used for buliding pages. If it is nil uses the default LibWiki style. Otherwise the values are used to override the default style for the pages created by this builder.",
	},
	result = {
		["builder"] = "A new page builder instance.",
	},
	type = "function",
}

symbols["PageBuilder:BeginPage"] = {
	summary = [[
Create a new blank page. Use the <<:object:PageBuilder|PageBuilder:Build*>> methods to populate it with content. When done building the page call <<:PageBuilder:EndPage>>. A page builder can build multiple pages at once and thus can be used to stretch out the build process over several frames for multiple pages simultaneously.

Important: Always call <<:PageBuilder:EndPage>> when done building it!]],
	signatures = {
		"page = PageBuilder:BeginPage(parent, width) -- Frame <- Frame, number",
	},
	parameter = {
		["parent"] = "The frame used as parent for the page.",
		["width"] = "The width of the area the page is displayed in.",
	},
	result = {
		["page"] = "The new page.",
	},
	type = "function",
}

symbols["PageBuilder:EndPage"] = {
	summary = [[
Finish a page previously created with <<:PageBuilder:BeginPage>>.]],
	signatures = {
		"PageBuilder:EndPage(page) -- Frame",
	},
	parameter = {
		["page"] = "The page to be finalized.",
	},
	result = {
	},
	type = "function",
}

symbols["PageBuilder:BuildHeader1"] = {
	summary = [[
Build a h1 header on the page at the current position.

Must be called between <<:PageBuilder:BeginPage>> and <<:PageBuilder:EndPage>>]],
	signatures = {
		"h1 = PageBuilder:BuildHeader1(page, title) -- H1 <- Frame, string",
		"h1 = PageBuilder:BuildHeader1(page, title, html) -- H1 <- Frame, string, boolean",
	},
	parameter = {
		["page"] = "The page to add the headaer to.",
		["title"] = "The string to be displayed on the title.",
		["html"] = "Controls whether HTML parsing is enabled for this header.",
	},
	result = {
		["h1"] = "An object identifying the header. Currently not used.",
	},
	type = "function",
	["Parses Link Markup"] = false,
}

symbols["PageBuilder:BuildHeader2"] = {
	summary = [[
Build a h2 header on the page at the current position.

Must be called between <<:PageBuilder:BeginPage>> and <<:PageBuilder:EndPage>>]],
	signatures = {
		"h2 = PageBuilder:BuildHeader2(page, title) -- H2 <- Frame, string",
		"h2 = PageBuilder:BuildHeader2(page, title, html) -- H2 <- Frame, string, boolean",
	},
	parameter = {
		["page"] = "The page to add the headaer to.",
		["title"] = "The string to be displayed on the title.",
		["html"] = "Controls whether HTML parsing is enabled for this header.",
	},
	result = {
		["h2"] = "An object identifying the header. Currently not used.",
	},
	type = "function",
	["Parses Link Markup"] = false,
}

symbols["PageBuilder:BuildParagraph"] = {
	summary = [[
Build a text paragraph on the page at the current position. Even though it is called "paragraph" there is no paragraph parsing logic involved.

Must be called between <<:PageBuilder:BeginPage>> and <<:PageBuilder:EndPage>>]],
	signatures = {
		"p = PageBuilder:BuildParagraph(page, text) -- P <- Frame, string",
		"p = PageBuilder:BuildParagraph(page, text, html) -- P <- Frame, string, boolean",
	},
	parameter = {
		["page"] = "The page to add the paragraph to.",
		["text"] = "The text to be displayed inside the paragraph.",
		["html"] = "Controls whether HTML parsing is enabled for this paragraph.",
	},
	result = {
		["p"] = "An object identifying the paragraph. Currently not used.",
	},
	type = "function",
	["Parses Link Markup"] = "If the html parameter is true.",
}

symbols["PageBuilder:BuildIndex"] = {
	summary = [[
Build a list of Text frames, arranged in a grid, containg the texts provided as argument.

Must be called between <<:PageBuilder:BeginPage>> and <<:PageBuilder:EndPage>>]],
	signatures = {
		"index = PageBuilder:BuildIndex(page, content) -- Index <- Frame, table",
		"index = PageBuilder:BuildIndex(page, content, html) -- Index <- Frame, table, boolean",
		"index = PageBuilder:BuildIndex(page, content, html, markup) -- Index <- Frame, table, boolean, boolean",
	},
	parameter = {
		["page"] = "The page to add the index to.",
		["content"] = "An array containing the strings to be displayed, arranged in a grid layout.",
		["html"] = "Controls whether HTML parsing is enabled for the index strings.",
		["markup"] = "True if content contains markup links which need to be processed first. Ignored if html is not true.",
	},
	result = {
		["index"] = "An object identifying the index. Currently not used.",
	},
	type = "function",
	["Parses Link Markup"] = "If the html parameter is true.",
}

symbols["PageBuilder:BuildFunctionSignatures"] = {
	summary = [[
Create a visualization of function signatures including the types and descriptions of its parameters and return values. The function parses it according to the same format as used by <<Rift:Inspect.Documentation>> to extract type information for parameters and return values. Following patterns are recognized:

	foo()
	x = foo() -- T1 &lt;- void
	x = foo(a) -- T1 &lt;- T2
	a, b = foo(a, b, c) -- T1, T2 &lt;- T3, T4, T5
	foo(a, b, ..., c) -- T1, T2/T3, ..., T4/T5
	
Where all placeholders can represent valid Lua identifiers. The types are mapped to the respective result or parameter and combined with the information provided to the function. Results and parameters may have the same name and are treated accordingly. An example result can be seen on this very page for the signatures of PageBuilder:BuildFunctionSignatures.

Must be called between <<:PageBuilder:BeginPage>> and <<:PageBuilder:EndPage>>]],
	signatures = {
		"signatures = PageBuilder:BuildFunctionSignatures(page, signatures, parameters, results) -- Signatures <- Frame, table, table, table",
		"signatures = PageBuilder:BuildFunctionSignatures(page, signatures, parameters, results, typeFormatCallback) -- Signatures <- Frame, table, table, table, function",
	},
	parameter = {
		["page"] = "The page to add the signatures to.",
		["parameters"] = "A table in the { name = description } format for filling out the parameters table.",
		["signatures"] = "An array containing the function signature strings.",
		["results"] = "A table in the { name = description } format for filling out the results table.",
		["typeFormatCallback"] = "An optional function to format the types extracted from the signatures, for example to replace them with hyperlinks to other pages. Takes a single string as argument and returns a single string.",
	},
	result = {
		["signatures"] = "An object identifying the signatures. Currently not used.",
	},
	type = "function",
	["Parses Link Markup"] = "If the html parameter is true most texts are searched including the return value of typeFormatCallback. Exceptions are: keys in tables, parameter/result names and the signatures.",
}

symbols["PageBuilder:BuildKeyValueTable"] = {
	summary = [[
Build a grid displaying arbitrary key-value coded table contents.

Must be called between <<:PageBuilder:BeginPage>> and <<:PageBuilder:EndPage>>]],
	signatures = {
		"kvt = PageBuilder:BuildKeyValueTable(page, t) -- Index <- Frame, table",
		"kvt = PageBuilder:BuildKeyValueTable(page, t, html) -- Index <- Frame, table, boolean",
	},
	parameter = {
		["page"] = "The page to add the index to.",
		["t"] = "A table with the contents to be displayed. The resulting view lists all entries sorted by keys. All keys and values are converted with tostring(). Nested tables are therefore not supported.",
		["html"] = "Controls whether HTML parsing is enabled for the keys and values.",
	},
	result = {
		["kvt"] = "An object identifying the grid. Currently not used.",
	},
	type = "function",
	["Parses Link Markup"] = "If the html parameter is true (only applies to table values).",
}

symbols["PageStyle"] = {
	summary = [[
A table controlling the style of pages created by a <<:object:PageBulder|PageBuilder>>. This page lists all supported fields and their types. It is arranged as a hierarchical nested table. A custom page style does not require all entries to be present. Those provided override the values of DefaultSeyle.

All colors are provided in HTMl notation, omitting the leading "#" sign.]],
	Members = {
		["padding"] = "The padding space between UI elements.",
		["h1.color"] = "h1 text color.",
		["h1.fontSize"] = "h1 font size.",
		["h1.glow"] = "h1 font glow effect. Either nil or a table compatible with Text:SetEffectGlow",
		["h2.color"] = "h2 text color.",
		["h2.fontSize"] = "h2 font size.",
		["h2.glow"] = "h2 font glow effect. Either nil or a table compatible with Text:SetEffectGlow",
		["p.color"] = "Paragraph text color.",
		["p.fontSize"] = "Paragraph font size.",
		["p.glow"] = "Paragraph font glow effect. Either nil or a table compatible with Text:SetEffectGlow",
		["code.parameter"] = "Color for function signature paramaters.",
		["code.result"] = "Color for function signature results.",
		["code.nil"] = "Color for function signature nil type.",
	},
}

symbols["DefaultStyle"] = {
	summary = [[
The default style used by LibWiki. Refer to PageStyle for explanations.]],
	Members = {
		["padding"] = "5",
		["h1.color"] = [[<font color="#fcf6cb">fcf6cb</font>]],
		["h1.fontSize"] = "16",
		["h1.glow"] = "{ blurX = 1.5, blurY = 1.5, strength = 4 }",
		["h2.color"] = [[<font color="#dbce9b">dbce9b</font>]],
		["h2.fontSize"] = "14",
		["h2.glow"] = "{ blurX = 1, blurY = 1, strength = 2 }",
		["p.color"] = [[<font color="#ffffff">ffffff</font>]],
		["p.fontSize"] = "13",
		["p.glow"] = "nil",
		["code.parameter"] = [[<font color="#92eaa1">92eaa1</font>]],
		["code.result"] = [[<font color="#ff9730">ff9730</font>]],
		["code.nil"] = [[<font color="#9f9f9e">9f9f9e</font>]],
	},
}

symbols["LibWiki.MakeHyperlinkMarkup"] = {
	summary = [[
Return the markup representation of a LibWiki page link.]],
	signatures = {
		"link = LibWiki.MakeHyperlinkMarkup(module, path) -- string <- string, string",
		"link = LibWiki.MakeHyperlinkMarkup(module, path, title) -- string <- string, string, string",
	},
	parameter = {
		["module"] = "The name of the module containing the page.",
		["path"] = "The path of the page to be linked.",
		["title"] = "The text to be displayed on the hyperlink or same as path if not present.",
	},
	result = {
		["link"] = "A string which can be embedded in a text and is translated into a hyperlink to other pages.",
	},
	type = "function",
}

symbols["LibWiki.MakeCopyHyperlinkMarkup"] = {
	summary = [[
Return the markup representation of a copy link. Instead of navigating to a new page it displays a small dialog with the given text  in a preselected textfield so it can be copied to the clipboard by the user.]],
	signatures = {
		"link = LibWiki.MakeCopyHyperlinkMarkup(text) -- string <- string",
		"link = LibWiki.MakeCopyHyperlinkMarkup(text, title) -- string <- string, string",
	},
	parameter = {
		["text"] = "The text to be copied.",
		["title"] = "The text to be displayed on the hyperlink or same as text if not present.",
	},
	result = {
		["link"] = "A string which can be embedded in a text and is translated into a hyperlink to a copy command.",
	},
	type = "function",
}

symbols["LibWiki.ShowCopyDialog"] = {
	summary = [[
Display a small dialog with the given text in a preselected textfield so it can be copied to the clipboard by the user.]],
	signatures = {
		"LibWiki.ShowCopyDialog(text) -- string",
	},
	parameter = {
		["text"] = "The text to be copied.",
	},
	result = {
	},
	type = "function",
}

symbols["Hyperlinks"] = {
	summary = [=[
You can use markup syntax to create links between pages. The usual suspects for wiki link markups are either [[xxx]] or {{xxx}} but since both can appear in common Lua snippets ApiBrowser uses &lt;&lt;xxx&gt;&gt; instead as both &lt;&lt; and &gt;&gt; are invalid Lua syntax. Most <<:object:PageBuilder|PageBuilder:Build*>> methods search the inputs for this markup text if HTML processing is enabled.

You have to escape &lt; and &gt; in normal text with &amp;lt; and &amp;gt;.

Remember the following rules:
<font color="#00ff00">Due to limitations in Lua's regex patterns the colon after &lt;&lt; must(!) be included otherwise the link is not recognized.</font>
<font color="#00C000">Do not use the colon character ":" in module names (it's OK in paths).</font>
<font color="#00ff00">Do not use the pipe character "|" in either module or path names (this also breaks Rift's HTML parser, so seriously, don't do it).</font>
<font color="#00C000">Link titles may contain HTML markup. In cases where the title ends with a "&gt;" append a semicolon ";" to resolve the ambiguity (e.g. "&lt;&lt;:Path|&lt;b&gt;Bold Title&lt;/b&gt;;&gt;&gt;"). The semicolon is not displayed.</font>

The following syntax combinations are recognized:]=],
	["<<:path>>"] = "Link to a page with the given path in the same module. The link text equals the path.",
	["<<:path|title>>"] = "Link to a page with the given path in the same module. The link text equals title.",
	["<<module:path>>"] = "Link to a page with the given path in the given module. The link text equals the path.",
	["<<module:path|title>>"] = "Link to a page with the given path in the given module. The link text equals title.",
}

symbols["Hyperlinks (commands)"] = {
	summary = [[
Some hyperlinks are not meant to simply navigate to a different page but instead exectue a command. This is implemented using module names in the link with special meaning. All these special module names begin with "#!" and cannot be used as ordinary module names.

All currently supported commands are listed on this page.]],
	["#!copy"] = [[
Display a small dialog with the given text in a preselected textfield so it can be copied to the clipboard by the user.
<font color="#ff8000">The text to be copied cannot contain the pipe "|" character!</font>

Example: <font color="#00ff00">&lt;&lt;#!copy:http://www.example.de|copy this&gt;&gt;</font>
Translates to: <<#!copy:http://www.example.de|copy this>>]],
}

symbols["Event.LibWiki.Navigator.PageChanging"] = {
	summary = [[
Signals that a <<:object:Navigator|Navigator>> is about to initiate a transition to a new page.]],
	signature = "Event.LibWiki.Navigator.PageChanging(handle, navigator, module, path, title) -- handleEventGlobal, Navigator, string, string, string",
	parameter = {
		["navigator"] = "The <<:object:Navigator|Navigator>> instance performing the page transition.",
		["module"] = "The module string of the new page.",
		["path"] = "The path string of the new page.",
		["title"] = "The title string of the new page.",
	},
	result = {
	},
	type = "event",
}

symbols["Event.LibWiki.Navigator.PageChanged"] = {
	summary = [[
Signals that a <<:object:Navigator|Navigator>> finished a transition to a new page.]],
	signature = "Event.LibWiki.Navigator.PageChanging(handle, navigator, module, path, title) -- handleEventGlobal, Navigator, string, string, string",
	parameter = {
		["navigator"] = "The <<:object:Navigator|Navigator>> instance performing the page transition.",
		["module"] = "The module string of the new page.",
		["path"] = "The path string of the new page.",
		["title"] = "The title string of the new page.",
	},
	result = {
	},
	type = "event",
}

LibWiki.ApiBrowserIndex = symbols
LibWiki.ApiBrowserInspect = function(path) return symbols[path] end
LibWiki.ApiBrowserSummary = [[LibWiki provides facilities to easily build, display and navigate Wiki-like pages.]]

end