local Addon, private = ...

setfenv(1, private)

-- Private methods
-- ============================================================================

local function buildKeyValueTable(self, page, style, module, t, html, createFrame)
	local keys = { }
	for k in pairs(t) do keys[#keys + 1] = tostring(k) end
	table.sort(keys)
	local owner = tostring(page)
	
	local keyWidth = 0
	local keyFrames = { }
	local valueFrames = { }
	for i = 1, #keys do
		local k = keys[i]
		local v = t[k]
		local keyFrame = createFrame("Text", "a", self, function(text)
				text:SetFontSize(style.p.fontSize)
				text:SetEffectGlow(style.p.glow)
				text:SetFontColor(ColorFromHtml(style.p.color))
			end)
		local valueFrame = createFrame("Text", "p", self, function(text)
			text:SetFontSize(style.p.fontSize)
			text:SetEffectGlow(style.p.glow)
			text:SetFontColor(ColorFromHtml(style.p.color))
			text:SetWordwrap(true)
		end)
		keyFrame:SetBackgroundColor(0.8, 0.8, 0.8, (i % 2 == 1) and 0.1 or 0)
		valueFrame:SetBackgroundColor(0.8, 0.8, 0.8, (i % 2 == 1) and 0.1 or 0)
		keyFrame:SetText(k, html)
		if(html) then
			valueFrame:SetText(MakeLinks(style, owner, module, tostring(v)), html)
		else
			valueFrame:SetText(tostring(v), html)
		end
		keyFrames[#keyFrames + 1] = keyFrame
		valueFrames[#valueFrames + 1] = valueFrame
		keyWidth = math.max(keyWidth, keyFrame:GetWidth())
	end
	for i = 1, #keyFrames do
		local keyFrame = keyFrames[i]
		local valueFrame = valueFrames[i]
		if(i == 1) then
			keyFrame:SetPoint("TOPLEFT", self, "TOPLEFT")
		else
			keyFrame:SetPoint("TOPLEFT", keyFrames[i - 1], "BOTTOMLEFT")
		end
		keyFrame:SetWidth(keyWidth)
		valueFrame:SetPoint("TOPLEFT", keyFrame, "TOPRIGHT", style.padding, 0)
		if(i == 1) then
			valueFrame:SetPoint("TOPRIGHT", self, "TOPRIGHT")
		else
			valueFrame:SetPoint("TOPRIGHT", valueFrames[i - 1], "BOTTOMRIGHT")
		end
		keyFrame:SetPoint("BOTTOM", valueFrame, "BOTTOM")
	end
	return valueFrames[#valueFrames]
end

-- Public methods
-- ============================================================================

Widgets = Widgets or { }

function Widgets.kvt(page, style, module, t, html, createFrame)
	local self = createFrame("Frame", "", page)
	local anchor

	if(next(t)) then
		bottom = buildKeyValueTable(self, page, style, module, t, html, createFrame)
		anchor = createFrame("Frame", "", self)
		anchor:SetVisible(false)
		anchor:SetPoint("TOPLEFT", self, "TOPLEFT")
		anchor:SetPoint("TOPRIGHT", self, "TOPRIGHT")
		anchor:SetPoint("BOTTOM", bottom, "BOTTOM")
	else
		self:SetHeight(1)
		anchor = self
	end
	
	return self, anchor, 0
end
